"""
    HCL AppScan on Cloud (v2)

    This API allows you to interact with the service. The API allows you to perform many of the operations available in the UI and more.</br>For authentication, use the relevant APIs in the Account section. A successful authentication response includes a bearer token for use in subsequent API calls. Pasting this token in the 'Access token' field above will automatically add the authorization header to any API call that requires a valid session.

    OpenAPI spec version: v2

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

from pyasoc.configuration import Configuration


class UserSiteCommonModelsUploadViewModel:
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "file_id": "str",
        "file_expiration": "datetime",
        "file_properties": "dict(str, object)",
    }

    attribute_map = {
        "file_id": "FileId",
        "file_expiration": "FileExpiration",
        "file_properties": "FileProperties",
    }

    def __init__(
        self,
        file_id=None,
        file_expiration=None,
        file_properties=None,
        _configuration=None,
    ):
        """UserSiteCommonModelsUploadViewModel - a model defined in Swagger"""
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._file_id = None
        self._file_expiration = None
        self._file_properties = None
        self.discriminator = None

        if file_id is not None:
            self.file_id = file_id
        if file_expiration is not None:
            self.file_expiration = file_expiration
        if file_properties is not None:
            self.file_properties = file_properties

    @property
    def file_id(self):
        # type: () -> str
        """Gets the file_id of this UserSiteCommonModelsUploadViewModel.


        :return: The file_id of this UserSiteCommonModelsUploadViewModel.
        :rtype: str
        """
        return self._file_id

    @file_id.setter
    def file_id(self, file_id):
        """Sets the file_id of this UserSiteCommonModelsUploadViewModel.


        :param file_id: The file_id of this UserSiteCommonModelsUploadViewModel.
        :type: str
        """

        self._file_id = file_id

    @property
    def file_expiration(self):
        # type: () -> datetime
        """Gets the file_expiration of this UserSiteCommonModelsUploadViewModel.


        :return: The file_expiration of this UserSiteCommonModelsUploadViewModel.
        :rtype: datetime
        """
        return self._file_expiration

    @file_expiration.setter
    def file_expiration(self, file_expiration):
        """Sets the file_expiration of this UserSiteCommonModelsUploadViewModel.


        :param file_expiration: The file_expiration of this UserSiteCommonModelsUploadViewModel.
        :type: datetime
        """

        self._file_expiration = file_expiration

    @property
    def file_properties(self):
        # type: () -> dict(str, object)
        """Gets the file_properties of this UserSiteCommonModelsUploadViewModel.


        :return: The file_properties of this UserSiteCommonModelsUploadViewModel.
        :rtype: dict(str, object)
        """
        return self._file_properties

    @file_properties.setter
    def file_properties(self, file_properties):
        """Sets the file_properties of this UserSiteCommonModelsUploadViewModel.


        :param file_properties: The file_properties of this UserSiteCommonModelsUploadViewModel.
        :type: dict(str, object)
        """

        self._file_properties = file_properties

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in self.swagger_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(UserSiteCommonModelsUploadViewModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserSiteCommonModelsUploadViewModel):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UserSiteCommonModelsUploadViewModel):
            return True

        return self.to_dict() != other.to_dict()
