"""
    HCL AppScan on Cloud (v2)

    This API allows you to interact with the service. The API allows you to perform many of the operations available in the UI and more.</br>For authentication, use the relevant APIs in the Account section. A successful authentication response includes a bearer token for use in subsequent API calls. Pasting this token in the 'Access token' field above will automatically add the authorization header to any API call that requires a valid session.

    OpenAPI spec version: v2

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

from pyasoc.configuration import Configuration


class MicrosoftDataEdmIEdmSchemaElement:
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {"schema_element_kind": "str", "namespace": "str", "name": "str"}

    attribute_map = {
        "schema_element_kind": "SchemaElementKind",
        "namespace": "Namespace",
        "name": "Name",
    }

    def __init__(self, schema_element_kind=None, namespace=None, name=None, _configuration=None):
        """MicrosoftDataEdmIEdmSchemaElement - a model defined in Swagger"""
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._schema_element_kind = None
        self._namespace = None
        self._name = None
        self.discriminator = None

        if schema_element_kind is not None:
            self.schema_element_kind = schema_element_kind
        if namespace is not None:
            self.namespace = namespace
        if name is not None:
            self.name = name

    @property
    def schema_element_kind(self):
        # type: () -> str
        """Gets the schema_element_kind of this MicrosoftDataEdmIEdmSchemaElement.


        :return: The schema_element_kind of this MicrosoftDataEdmIEdmSchemaElement.
        :rtype: str
        """
        return self._schema_element_kind

    @schema_element_kind.setter
    def schema_element_kind(self, schema_element_kind):
        """Sets the schema_element_kind of this MicrosoftDataEdmIEdmSchemaElement.


        :param schema_element_kind: The schema_element_kind of this MicrosoftDataEdmIEdmSchemaElement.
        :type: str
        """
        allowed_values = [
            "None",
            "TypeDefinition",
            "Function",
            "ValueTerm",
            "EntityContainer",
        ]
        if self._configuration.client_side_validation and schema_element_kind not in allowed_values:
            raise ValueError(
                "Invalid value for `schema_element_kind` ({}), must be one of {}".format(
                    schema_element_kind, allowed_values
                )
            )

        self._schema_element_kind = schema_element_kind

    @property
    def namespace(self):
        # type: () -> str
        """Gets the namespace of this MicrosoftDataEdmIEdmSchemaElement.


        :return: The namespace of this MicrosoftDataEdmIEdmSchemaElement.
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """Sets the namespace of this MicrosoftDataEdmIEdmSchemaElement.


        :param namespace: The namespace of this MicrosoftDataEdmIEdmSchemaElement.
        :type: str
        """

        self._namespace = namespace

    @property
    def name(self):
        # type: () -> str
        """Gets the name of this MicrosoftDataEdmIEdmSchemaElement.


        :return: The name of this MicrosoftDataEdmIEdmSchemaElement.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this MicrosoftDataEdmIEdmSchemaElement.


        :param name: The name of this MicrosoftDataEdmIEdmSchemaElement.
        :type: str
        """

        self._name = name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in self.swagger_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(MicrosoftDataEdmIEdmSchemaElement, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MicrosoftDataEdmIEdmSchemaElement):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MicrosoftDataEdmIEdmSchemaElement):
            return True

        return self.to_dict() != other.to_dict()
