"""
    HCL AppScan on Cloud (v2)

    This API allows you to interact with the service. The API allows you to perform many of the operations available in the UI and more.</br>For authentication, use the relevant APIs in the Account section. A successful authentication response includes a bearer token for use in subsequent API calls. Pasting this token in the 'Access token' field above will automatically add the authorization header to any API call that requires a valid session.

    OpenAPI spec version: v2

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

from pyasoc.configuration import Configuration


class SystemWebHttpODataQuerySelectExpandQueryOption:
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "context": "SystemWebHttpODataODataQueryContext",
        "raw_select": "str",
        "raw_expand": "str",
        "validator": "SystemWebHttpODataQueryValidatorsSelectExpandQueryValidator",
        "select_expand_clause": "MicrosoftDataODataQuerySemanticAstSelectExpandClause",
    }

    attribute_map = {
        "context": "Context",
        "raw_select": "RawSelect",
        "raw_expand": "RawExpand",
        "validator": "Validator",
        "select_expand_clause": "SelectExpandClause",
    }

    def __init__(
        self,
        context=None,
        raw_select=None,
        raw_expand=None,
        validator=None,
        select_expand_clause=None,
        _configuration=None,
    ):
        """SystemWebHttpODataQuerySelectExpandQueryOption - a model defined in Swagger"""
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._context = None
        self._raw_select = None
        self._raw_expand = None
        self._validator = None
        self._select_expand_clause = None
        self.discriminator = None

        if context is not None:
            self.context = context
        if raw_select is not None:
            self.raw_select = raw_select
        if raw_expand is not None:
            self.raw_expand = raw_expand
        if validator is not None:
            self.validator = validator
        if select_expand_clause is not None:
            self.select_expand_clause = select_expand_clause

    @property
    def context(self):
        # type: () -> SystemWebHttpODataODataQueryContext
        """Gets the context of this SystemWebHttpODataQuerySelectExpandQueryOption.


        :return: The context of this SystemWebHttpODataQuerySelectExpandQueryOption.
        :rtype: SystemWebHttpODataODataQueryContext
        """
        return self._context

    @context.setter
    def context(self, context):
        """Sets the context of this SystemWebHttpODataQuerySelectExpandQueryOption.


        :param context: The context of this SystemWebHttpODataQuerySelectExpandQueryOption.
        :type: SystemWebHttpODataODataQueryContext
        """

        self._context = context

    @property
    def raw_select(self):
        # type: () -> str
        """Gets the raw_select of this SystemWebHttpODataQuerySelectExpandQueryOption.


        :return: The raw_select of this SystemWebHttpODataQuerySelectExpandQueryOption.
        :rtype: str
        """
        return self._raw_select

    @raw_select.setter
    def raw_select(self, raw_select):
        """Sets the raw_select of this SystemWebHttpODataQuerySelectExpandQueryOption.


        :param raw_select: The raw_select of this SystemWebHttpODataQuerySelectExpandQueryOption.
        :type: str
        """

        self._raw_select = raw_select

    @property
    def raw_expand(self):
        # type: () -> str
        """Gets the raw_expand of this SystemWebHttpODataQuerySelectExpandQueryOption.


        :return: The raw_expand of this SystemWebHttpODataQuerySelectExpandQueryOption.
        :rtype: str
        """
        return self._raw_expand

    @raw_expand.setter
    def raw_expand(self, raw_expand):
        """Sets the raw_expand of this SystemWebHttpODataQuerySelectExpandQueryOption.


        :param raw_expand: The raw_expand of this SystemWebHttpODataQuerySelectExpandQueryOption.
        :type: str
        """

        self._raw_expand = raw_expand

    @property
    def validator(self):
        # type: () -> SystemWebHttpODataQueryValidatorsSelectExpandQueryValidator
        """Gets the validator of this SystemWebHttpODataQuerySelectExpandQueryOption.


        :return: The validator of this SystemWebHttpODataQuerySelectExpandQueryOption.
        :rtype: SystemWebHttpODataQueryValidatorsSelectExpandQueryValidator
        """
        return self._validator

    @validator.setter
    def validator(self, validator):
        """Sets the validator of this SystemWebHttpODataQuerySelectExpandQueryOption.


        :param validator: The validator of this SystemWebHttpODataQuerySelectExpandQueryOption.
        :type: SystemWebHttpODataQueryValidatorsSelectExpandQueryValidator
        """

        self._validator = validator

    @property
    def select_expand_clause(self):
        # type: () -> MicrosoftDataODataQuerySemanticAstSelectExpandClause
        """Gets the select_expand_clause of this SystemWebHttpODataQuerySelectExpandQueryOption.


        :return: The select_expand_clause of this SystemWebHttpODataQuerySelectExpandQueryOption.
        :rtype: MicrosoftDataODataQuerySemanticAstSelectExpandClause
        """
        return self._select_expand_clause

    @select_expand_clause.setter
    def select_expand_clause(self, select_expand_clause):
        """Sets the select_expand_clause of this SystemWebHttpODataQuerySelectExpandQueryOption.


        :param select_expand_clause: The select_expand_clause of this SystemWebHttpODataQuerySelectExpandQueryOption.
        :type: MicrosoftDataODataQuerySemanticAstSelectExpandClause
        """

        self._select_expand_clause = select_expand_clause

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in self.swagger_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(SystemWebHttpODataQuerySelectExpandQueryOption, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SystemWebHttpODataQuerySelectExpandQueryOption):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SystemWebHttpODataQuerySelectExpandQueryOption):
            return True

        return self.to_dict() != other.to_dict()
