"""
    HCL AppScan on Cloud (v2)

    This API allows you to interact with the service. The API allows you to perform many of the operations available in the UI and more.</br>For authentication, use the relevant APIs in the Account section. A successful authentication response includes a bearer token for use in subsequent API calls. Pasting this token in the 'Access token' field above will automatically add the authorization header to any API call that requires a valid session.

    OpenAPI spec version: v2

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

from pyasoc.configuration import Configuration


class UserSiteCommonModelsUpdateIastScan:
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "config_file_id": "str",
        "name": "str",
        "enable_mail_notifications": "bool",
        "locale": "str",
        "fully_automatic": "bool",
    }

    attribute_map = {
        "config_file_id": "ConfigFileId",
        "name": "Name",
        "enable_mail_notifications": "EnableMailNotifications",
        "locale": "Locale",
        "fully_automatic": "FullyAutomatic",
    }

    def __init__(
        self,
        config_file_id=None,
        name=None,
        enable_mail_notifications=None,
        locale=None,
        fully_automatic=None,
        _configuration=None,
    ):
        """UserSiteCommonModelsUpdateIastScan - a model defined in Swagger"""
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._config_file_id = None
        self._name = None
        self._enable_mail_notifications = None
        self._locale = None
        self._fully_automatic = None
        self.discriminator = None

        if config_file_id is not None:
            self.config_file_id = config_file_id
        if name is not None:
            self.name = name
        if enable_mail_notifications is not None:
            self.enable_mail_notifications = enable_mail_notifications
        if locale is not None:
            self.locale = locale
        if fully_automatic is not None:
            self.fully_automatic = fully_automatic

    @property
    def config_file_id(self):
        # type: () -> str
        """Gets the config_file_id of this UserSiteCommonModelsUpdateIastScan.


        :return: The config_file_id of this UserSiteCommonModelsUpdateIastScan.
        :rtype: str
        """
        return self._config_file_id

    @config_file_id.setter
    def config_file_id(self, config_file_id):
        """Sets the config_file_id of this UserSiteCommonModelsUpdateIastScan.


        :param config_file_id: The config_file_id of this UserSiteCommonModelsUpdateIastScan.
        :type: str
        """

        self._config_file_id = config_file_id

    @property
    def name(self):
        # type: () -> str
        """Gets the name of this UserSiteCommonModelsUpdateIastScan.


        :return: The name of this UserSiteCommonModelsUpdateIastScan.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this UserSiteCommonModelsUpdateIastScan.


        :param name: The name of this UserSiteCommonModelsUpdateIastScan.
        :type: str
        """
        if self._configuration.client_side_validation and name is not None and len(name) > 1024:
            raise ValueError(
                "Invalid value for `name`, length must be less than or equal to `1024`"
            )
        if self._configuration.client_side_validation and name is not None and len(name) < 1:
            raise ValueError(
                "Invalid value for `name`, length must be greater than or equal to `1`"
            )

        self._name = name

    @property
    def enable_mail_notifications(self):
        # type: () -> bool
        """Gets the enable_mail_notifications of this UserSiteCommonModelsUpdateIastScan.


        :return: The enable_mail_notifications of this UserSiteCommonModelsUpdateIastScan.
        :rtype: bool
        """
        return self._enable_mail_notifications

    @enable_mail_notifications.setter
    def enable_mail_notifications(self, enable_mail_notifications):
        """Sets the enable_mail_notifications of this UserSiteCommonModelsUpdateIastScan.


        :param enable_mail_notifications: The enable_mail_notifications of this UserSiteCommonModelsUpdateIastScan.
        :type: bool
        """

        self._enable_mail_notifications = enable_mail_notifications

    @property
    def locale(self):
        # type: () -> str
        """Gets the locale of this UserSiteCommonModelsUpdateIastScan.


        :return: The locale of this UserSiteCommonModelsUpdateIastScan.
        :rtype: str
        """
        return self._locale

    @locale.setter
    def locale(self, locale):
        """Sets the locale of this UserSiteCommonModelsUpdateIastScan.


        :param locale: The locale of this UserSiteCommonModelsUpdateIastScan.
        :type: str
        """
        if self._configuration.client_side_validation and locale is not None and len(locale) > 10:
            raise ValueError(
                "Invalid value for `locale`, length must be less than or equal to `10`"
            )
        if self._configuration.client_side_validation and locale is not None and len(locale) < 0:
            raise ValueError(
                "Invalid value for `locale`, length must be greater than or equal to `0`"
            )

        self._locale = locale

    @property
    def fully_automatic(self):
        # type: () -> bool
        """Gets the fully_automatic of this UserSiteCommonModelsUpdateIastScan.


        :return: The fully_automatic of this UserSiteCommonModelsUpdateIastScan.
        :rtype: bool
        """
        return self._fully_automatic

    @fully_automatic.setter
    def fully_automatic(self, fully_automatic):
        """Sets the fully_automatic of this UserSiteCommonModelsUpdateIastScan.


        :param fully_automatic: The fully_automatic of this UserSiteCommonModelsUpdateIastScan.
        :type: bool
        """

        self._fully_automatic = fully_automatic

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in self.swagger_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(UserSiteCommonModelsUpdateIastScan, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserSiteCommonModelsUpdateIastScan):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UserSiteCommonModelsUpdateIastScan):
            return True

        return self.to_dict() != other.to_dict()
