"""
    HCL AppScan on Cloud (v2)

    This API allows you to interact with the service. The API allows you to perform many of the operations available in the UI and more.</br>For authentication, use the relevant APIs in the Account section. A successful authentication response includes a bearer token for use in subsequent API calls. Pasting this token in the 'Access token' field above will automatically add the authorization header to any API call that requires a valid session.

    OpenAPI spec version: v2

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

from pyasoc.configuration import Configuration


class UserSiteCommonModelsTriageResult:
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "n_provided_issues": "int",
        "n_updated_issues": "int",
        "n_inherited_issues": "int",
        "n_status_conflict_issues": "int",
    }

    attribute_map = {
        "n_provided_issues": "NProvidedIssues",
        "n_updated_issues": "NUpdatedIssues",
        "n_inherited_issues": "NInheritedIssues",
        "n_status_conflict_issues": "NStatusConflictIssues",
    }

    def __init__(
        self,
        n_provided_issues=None,
        n_updated_issues=None,
        n_inherited_issues=None,
        n_status_conflict_issues=None,
        _configuration=None,
    ):
        """UserSiteCommonModelsTriageResult - a model defined in Swagger"""
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._n_provided_issues = None
        self._n_updated_issues = None
        self._n_inherited_issues = None
        self._n_status_conflict_issues = None
        self.discriminator = None

        if n_provided_issues is not None:
            self.n_provided_issues = n_provided_issues
        if n_updated_issues is not None:
            self.n_updated_issues = n_updated_issues
        if n_inherited_issues is not None:
            self.n_inherited_issues = n_inherited_issues
        if n_status_conflict_issues is not None:
            self.n_status_conflict_issues = n_status_conflict_issues

    @property
    def n_provided_issues(self):
        # type: () -> int
        """Gets the n_provided_issues of this UserSiteCommonModelsTriageResult.


        :return: The n_provided_issues of this UserSiteCommonModelsTriageResult.
        :rtype: int
        """
        return self._n_provided_issues

    @n_provided_issues.setter
    def n_provided_issues(self, n_provided_issues):
        """Sets the n_provided_issues of this UserSiteCommonModelsTriageResult.


        :param n_provided_issues: The n_provided_issues of this UserSiteCommonModelsTriageResult.
        :type: int
        """

        self._n_provided_issues = n_provided_issues

    @property
    def n_updated_issues(self):
        # type: () -> int
        """Gets the n_updated_issues of this UserSiteCommonModelsTriageResult.


        :return: The n_updated_issues of this UserSiteCommonModelsTriageResult.
        :rtype: int
        """
        return self._n_updated_issues

    @n_updated_issues.setter
    def n_updated_issues(self, n_updated_issues):
        """Sets the n_updated_issues of this UserSiteCommonModelsTriageResult.


        :param n_updated_issues: The n_updated_issues of this UserSiteCommonModelsTriageResult.
        :type: int
        """

        self._n_updated_issues = n_updated_issues

    @property
    def n_inherited_issues(self):
        # type: () -> int
        """Gets the n_inherited_issues of this UserSiteCommonModelsTriageResult.


        :return: The n_inherited_issues of this UserSiteCommonModelsTriageResult.
        :rtype: int
        """
        return self._n_inherited_issues

    @n_inherited_issues.setter
    def n_inherited_issues(self, n_inherited_issues):
        """Sets the n_inherited_issues of this UserSiteCommonModelsTriageResult.


        :param n_inherited_issues: The n_inherited_issues of this UserSiteCommonModelsTriageResult.
        :type: int
        """

        self._n_inherited_issues = n_inherited_issues

    @property
    def n_status_conflict_issues(self):
        # type: () -> int
        """Gets the n_status_conflict_issues of this UserSiteCommonModelsTriageResult.


        :return: The n_status_conflict_issues of this UserSiteCommonModelsTriageResult.
        :rtype: int
        """
        return self._n_status_conflict_issues

    @n_status_conflict_issues.setter
    def n_status_conflict_issues(self, n_status_conflict_issues):
        """Sets the n_status_conflict_issues of this UserSiteCommonModelsTriageResult.


        :param n_status_conflict_issues: The n_status_conflict_issues of this UserSiteCommonModelsTriageResult.
        :type: int
        """

        self._n_status_conflict_issues = n_status_conflict_issues

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in self.swagger_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(UserSiteCommonModelsTriageResult, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserSiteCommonModelsTriageResult):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UserSiteCommonModelsTriageResult):
            return True

        return self.to_dict() != other.to_dict()
