"""
    HCL AppScan on Cloud (v2)

    This API allows you to interact with the service. The API allows you to perform many of the operations available in the UI and more.</br>For authentication, use the relevant APIs in the Account section. A successful authentication response includes a bearer token for use in subsequent API calls. Pasting this token in the 'Access token' field above will automatically add the authorization header to any API call that requires a valid session.

    OpenAPI spec version: v2

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

from pyasoc.configuration import Configuration


class ScanManagerScanModelsPostmanCollectionFiles:
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "collection_json_file_id": "str",
        "environment_json_file_id": "str",
        "global_json_file_id": "str",
        "additional_zip_file_id": "str",
    }

    attribute_map = {
        "collection_json_file_id": "CollectionJsonFileId",
        "environment_json_file_id": "EnvironmentJsonFileId",
        "global_json_file_id": "GlobalJsonFileId",
        "additional_zip_file_id": "AdditionalZipFileId",
    }

    def __init__(
        self,
        collection_json_file_id=None,
        environment_json_file_id=None,
        global_json_file_id=None,
        additional_zip_file_id=None,
        _configuration=None,
    ):
        """ScanManagerScanModelsPostmanCollectionFiles - a model defined in Swagger"""
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._collection_json_file_id = None
        self._environment_json_file_id = None
        self._global_json_file_id = None
        self._additional_zip_file_id = None
        self.discriminator = None

        if collection_json_file_id is not None:
            self.collection_json_file_id = collection_json_file_id
        if environment_json_file_id is not None:
            self.environment_json_file_id = environment_json_file_id
        if global_json_file_id is not None:
            self.global_json_file_id = global_json_file_id
        if additional_zip_file_id is not None:
            self.additional_zip_file_id = additional_zip_file_id

    @property
    def collection_json_file_id(self):
        # type: () -> str
        """Gets the collection_json_file_id of this ScanManagerScanModelsPostmanCollectionFiles.


        :return: The collection_json_file_id of this ScanManagerScanModelsPostmanCollectionFiles.
        :rtype: str
        """
        return self._collection_json_file_id

    @collection_json_file_id.setter
    def collection_json_file_id(self, collection_json_file_id):
        """Sets the collection_json_file_id of this ScanManagerScanModelsPostmanCollectionFiles.


        :param collection_json_file_id: The collection_json_file_id of this ScanManagerScanModelsPostmanCollectionFiles.
        :type: str
        """

        self._collection_json_file_id = collection_json_file_id

    @property
    def environment_json_file_id(self):
        # type: () -> str
        """Gets the environment_json_file_id of this ScanManagerScanModelsPostmanCollectionFiles.


        :return: The environment_json_file_id of this ScanManagerScanModelsPostmanCollectionFiles.
        :rtype: str
        """
        return self._environment_json_file_id

    @environment_json_file_id.setter
    def environment_json_file_id(self, environment_json_file_id):
        """Sets the environment_json_file_id of this ScanManagerScanModelsPostmanCollectionFiles.


        :param environment_json_file_id: The environment_json_file_id of this ScanManagerScanModelsPostmanCollectionFiles.
        :type: str
        """

        self._environment_json_file_id = environment_json_file_id

    @property
    def global_json_file_id(self):
        # type: () -> str
        """Gets the global_json_file_id of this ScanManagerScanModelsPostmanCollectionFiles.


        :return: The global_json_file_id of this ScanManagerScanModelsPostmanCollectionFiles.
        :rtype: str
        """
        return self._global_json_file_id

    @global_json_file_id.setter
    def global_json_file_id(self, global_json_file_id):
        """Sets the global_json_file_id of this ScanManagerScanModelsPostmanCollectionFiles.


        :param global_json_file_id: The global_json_file_id of this ScanManagerScanModelsPostmanCollectionFiles.
        :type: str
        """

        self._global_json_file_id = global_json_file_id

    @property
    def additional_zip_file_id(self):
        # type: () -> str
        """Gets the additional_zip_file_id of this ScanManagerScanModelsPostmanCollectionFiles.


        :return: The additional_zip_file_id of this ScanManagerScanModelsPostmanCollectionFiles.
        :rtype: str
        """
        return self._additional_zip_file_id

    @additional_zip_file_id.setter
    def additional_zip_file_id(self, additional_zip_file_id):
        """Sets the additional_zip_file_id of this ScanManagerScanModelsPostmanCollectionFiles.


        :param additional_zip_file_id: The additional_zip_file_id of this ScanManagerScanModelsPostmanCollectionFiles.
        :type: str
        """

        self._additional_zip_file_id = additional_zip_file_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in self.swagger_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(ScanManagerScanModelsPostmanCollectionFiles, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ScanManagerScanModelsPostmanCollectionFiles):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ScanManagerScanModelsPostmanCollectionFiles):
            return True

        return self.to_dict() != other.to_dict()
