"""
    HCL AppScan on Cloud (v2)

    This API allows you to interact with the service. The API allows you to perform many of the operations available in the UI and more.</br>For authentication, use the relevant APIs in the Account section. A successful authentication response includes a bearer token for use in subsequent API calls. Pasting this token in the 'Access token' field above will automatically add the authorization header to any API call that requires a valid session.

    OpenAPI spec version: v2

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

from pyasoc.configuration import Configuration


class UserSiteCommonModelsSecurityReportJob:
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "configuration": "UtilitiesStructuresSecurityReportOptions",
        "odata_filter": "str",
        "apply_policies": "str",
        "select_policy_ids": "list[str]",
    }

    attribute_map = {
        "configuration": "Configuration",
        "odata_filter": "OdataFilter",
        "apply_policies": "ApplyPolicies",
        "select_policy_ids": "SelectPolicyIds",
    }

    def __init__(
        self,
        configuration=None,
        odata_filter=None,
        apply_policies=None,
        select_policy_ids=None,
        _configuration=None,
    ):
        """UserSiteCommonModelsSecurityReportJob - a model defined in Swagger"""
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._configuration = None
        self._odata_filter = None
        self._apply_policies = None
        self._select_policy_ids = None
        self.discriminator = None

        self.configuration = configuration
        if odata_filter is not None:
            self.odata_filter = odata_filter
        if apply_policies is not None:
            self.apply_policies = apply_policies
        if select_policy_ids is not None:
            self.select_policy_ids = select_policy_ids

    @property
    def configuration(self):
        # type: () -> UtilitiesStructuresSecurityReportOptions
        """Gets the configuration of this UserSiteCommonModelsSecurityReportJob.


        :return: The configuration of this UserSiteCommonModelsSecurityReportJob.
        :rtype: UtilitiesStructuresSecurityReportOptions
        """
        return self._configuration

    @configuration.setter
    def configuration(self, configuration):
        """Sets the configuration of this UserSiteCommonModelsSecurityReportJob.


        :param configuration: The configuration of this UserSiteCommonModelsSecurityReportJob.
        :type: UtilitiesStructuresSecurityReportOptions
        """
        if self._configuration.client_side_validation and configuration is None:
            raise ValueError("Invalid value for `configuration`, must not be `None`")

        self._configuration = configuration

    @property
    def odata_filter(self):
        # type: () -> str
        """Gets the odata_filter of this UserSiteCommonModelsSecurityReportJob.


        :return: The odata_filter of this UserSiteCommonModelsSecurityReportJob.
        :rtype: str
        """
        return self._odata_filter

    @odata_filter.setter
    def odata_filter(self, odata_filter):
        """Sets the odata_filter of this UserSiteCommonModelsSecurityReportJob.


        :param odata_filter: The odata_filter of this UserSiteCommonModelsSecurityReportJob.
        :type: str
        """

        self._odata_filter = odata_filter

    @property
    def apply_policies(self):
        # type: () -> str
        """Gets the apply_policies of this UserSiteCommonModelsSecurityReportJob.


        :return: The apply_policies of this UserSiteCommonModelsSecurityReportJob.
        :rtype: str
        """
        return self._apply_policies

    @apply_policies.setter
    def apply_policies(self, apply_policies):
        """Sets the apply_policies of this UserSiteCommonModelsSecurityReportJob.


        :param apply_policies: The apply_policies of this UserSiteCommonModelsSecurityReportJob.
        :type: str
        """
        allowed_values = ["None", "All", "Select"]
        if self._configuration.client_side_validation and apply_policies not in allowed_values:
            raise ValueError(
                "Invalid value for `apply_policies` ({}), must be one of {}".format(
                    apply_policies, allowed_values
                )
            )

        self._apply_policies = apply_policies

    @property
    def select_policy_ids(self):
        # type: () -> list[str]
        """Gets the select_policy_ids of this UserSiteCommonModelsSecurityReportJob.


        :return: The select_policy_ids of this UserSiteCommonModelsSecurityReportJob.
        :rtype: list[str]
        """
        return self._select_policy_ids

    @select_policy_ids.setter
    def select_policy_ids(self, select_policy_ids):
        """Sets the select_policy_ids of this UserSiteCommonModelsSecurityReportJob.


        :param select_policy_ids: The select_policy_ids of this UserSiteCommonModelsSecurityReportJob.
        :type: list[str]
        """

        self._select_policy_ids = select_policy_ids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in self.swagger_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(UserSiteCommonModelsSecurityReportJob, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserSiteCommonModelsSecurityReportJob):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UserSiteCommonModelsSecurityReportJob):
            return True

        return self.to_dict() != other.to_dict()
