"""
    HCL AppScan on Cloud (v2)

    This API allows you to interact with the service. The API allows you to perform many of the operations available in the UI and more.</br>For authentication, use the relevant APIs in the Account section. A successful authentication response includes a bearer token for use in subsequent API calls. Pasting this token in the 'Access token' field above will automatically add the authorization header to any API call that requires a valid session.

    OpenAPI spec version: v2

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

from pyasoc.configuration import Configuration


class UserSiteCommonModelsAssetGroupModel:
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "id": "str",
        "name": "str",
        "description": "str",
        "is_default": "bool",
        "contact_person": "UserSiteCommonModelsBasicUserInfo",
        "apps_count": "int",
        "users_count": "int",
        "issues_status_inheritance": "str",
    }

    attribute_map = {
        "id": "Id",
        "name": "Name",
        "description": "Description",
        "is_default": "IsDefault",
        "contact_person": "ContactPerson",
        "apps_count": "AppsCount",
        "users_count": "UsersCount",
        "issues_status_inheritance": "IssuesStatusInheritance",
    }

    def __init__(
        self,
        id=None,
        name=None,
        description=None,
        is_default=None,
        contact_person=None,
        apps_count=None,
        users_count=None,
        issues_status_inheritance=None,
        _configuration=None,
    ):
        """UserSiteCommonModelsAssetGroupModel - a model defined in Swagger"""
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._name = None
        self._description = None
        self._is_default = None
        self._contact_person = None
        self._apps_count = None
        self._users_count = None
        self._issues_status_inheritance = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if description is not None:
            self.description = description
        if is_default is not None:
            self.is_default = is_default
        if contact_person is not None:
            self.contact_person = contact_person
        if apps_count is not None:
            self.apps_count = apps_count
        if users_count is not None:
            self.users_count = users_count
        if issues_status_inheritance is not None:
            self.issues_status_inheritance = issues_status_inheritance

    @property
    def id(self):
        # type: () -> str
        """Gets the id of this UserSiteCommonModelsAssetGroupModel.


        :return: The id of this UserSiteCommonModelsAssetGroupModel.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this UserSiteCommonModelsAssetGroupModel.


        :param id: The id of this UserSiteCommonModelsAssetGroupModel.
        :type: str
        """

        self._id = id

    @property
    def name(self):
        # type: () -> str
        """Gets the name of this UserSiteCommonModelsAssetGroupModel.


        :return: The name of this UserSiteCommonModelsAssetGroupModel.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this UserSiteCommonModelsAssetGroupModel.


        :param name: The name of this UserSiteCommonModelsAssetGroupModel.
        :type: str
        """
        if self._configuration.client_side_validation and name is not None and len(name) > 120:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `120`")
        if self._configuration.client_side_validation and name is not None and len(name) < 0:
            raise ValueError(
                "Invalid value for `name`, length must be greater than or equal to `0`"
            )

        self._name = name

    @property
    def description(self):
        # type: () -> str
        """Gets the description of this UserSiteCommonModelsAssetGroupModel.


        :return: The description of this UserSiteCommonModelsAssetGroupModel.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this UserSiteCommonModelsAssetGroupModel.


        :param description: The description of this UserSiteCommonModelsAssetGroupModel.
        :type: str
        """

        self._description = description

    @property
    def is_default(self):
        # type: () -> bool
        """Gets the is_default of this UserSiteCommonModelsAssetGroupModel.


        :return: The is_default of this UserSiteCommonModelsAssetGroupModel.
        :rtype: bool
        """
        return self._is_default

    @is_default.setter
    def is_default(self, is_default):
        """Sets the is_default of this UserSiteCommonModelsAssetGroupModel.


        :param is_default: The is_default of this UserSiteCommonModelsAssetGroupModel.
        :type: bool
        """

        self._is_default = is_default

    @property
    def contact_person(self):
        # type: () -> UserSiteCommonModelsBasicUserInfo
        """Gets the contact_person of this UserSiteCommonModelsAssetGroupModel.


        :return: The contact_person of this UserSiteCommonModelsAssetGroupModel.
        :rtype: UserSiteCommonModelsBasicUserInfo
        """
        return self._contact_person

    @contact_person.setter
    def contact_person(self, contact_person):
        """Sets the contact_person of this UserSiteCommonModelsAssetGroupModel.


        :param contact_person: The contact_person of this UserSiteCommonModelsAssetGroupModel.
        :type: UserSiteCommonModelsBasicUserInfo
        """

        self._contact_person = contact_person

    @property
    def apps_count(self):
        # type: () -> int
        """Gets the apps_count of this UserSiteCommonModelsAssetGroupModel.


        :return: The apps_count of this UserSiteCommonModelsAssetGroupModel.
        :rtype: int
        """
        return self._apps_count

    @apps_count.setter
    def apps_count(self, apps_count):
        """Sets the apps_count of this UserSiteCommonModelsAssetGroupModel.


        :param apps_count: The apps_count of this UserSiteCommonModelsAssetGroupModel.
        :type: int
        """

        self._apps_count = apps_count

    @property
    def users_count(self):
        # type: () -> int
        """Gets the users_count of this UserSiteCommonModelsAssetGroupModel.


        :return: The users_count of this UserSiteCommonModelsAssetGroupModel.
        :rtype: int
        """
        return self._users_count

    @users_count.setter
    def users_count(self, users_count):
        """Sets the users_count of this UserSiteCommonModelsAssetGroupModel.


        :param users_count: The users_count of this UserSiteCommonModelsAssetGroupModel.
        :type: int
        """

        self._users_count = users_count

    @property
    def issues_status_inheritance(self):
        # type: () -> str
        """Gets the issues_status_inheritance of this UserSiteCommonModelsAssetGroupModel.


        :return: The issues_status_inheritance of this UserSiteCommonModelsAssetGroupModel.
        :rtype: str
        """
        return self._issues_status_inheritance

    @issues_status_inheritance.setter
    def issues_status_inheritance(self, issues_status_inheritance):
        """Sets the issues_status_inheritance of this UserSiteCommonModelsAssetGroupModel.


        :param issues_status_inheritance: The issues_status_inheritance of this UserSiteCommonModelsAssetGroupModel.
        :type: str
        """
        allowed_values = ["None", "Noise", "Fixed"]
        if (
            self._configuration.client_side_validation
            and issues_status_inheritance not in allowed_values
        ):
            raise ValueError(
                "Invalid value for `issues_status_inheritance` ({}), must be one of {}".format(
                    issues_status_inheritance, allowed_values
                )
            )

        self._issues_status_inheritance = issues_status_inheritance

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in self.swagger_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(UserSiteCommonModelsAssetGroupModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserSiteCommonModelsAssetGroupModel):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UserSiteCommonModelsAssetGroupModel):
            return True

        return self.to_dict() != other.to_dict()
