"""
    HCL AppScan on Cloud (v2)

    This API allows you to interact with the service. The API allows you to perform many of the operations available in the UI and more.</br>For authentication, use the relevant APIs in the Account section. A successful authentication response includes a bearer token for use in subsequent API calls. Pasting this token in the 'Access token' field above will automatically add the authorization header to any API call that requires a valid session.

    OpenAPI spec version: v2

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

from pyasoc.configuration import Configuration


class UserSiteCommonModelsBasicUserInfo:
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "id": "str",
        "first_name": "str",
        "last_name": "str",
        "user_name": "str",
        "email": "str",
    }

    attribute_map = {
        "id": "Id",
        "first_name": "FirstName",
        "last_name": "LastName",
        "user_name": "UserName",
        "email": "Email",
    }

    def __init__(
        self,
        id=None,
        first_name=None,
        last_name=None,
        user_name=None,
        email=None,
        _configuration=None,
    ):
        """UserSiteCommonModelsBasicUserInfo - a model defined in Swagger"""
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._first_name = None
        self._last_name = None
        self._user_name = None
        self._email = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if first_name is not None:
            self.first_name = first_name
        if last_name is not None:
            self.last_name = last_name
        if user_name is not None:
            self.user_name = user_name
        if email is not None:
            self.email = email

    @property
    def id(self):
        # type: () -> str
        """Gets the id of this UserSiteCommonModelsBasicUserInfo.


        :return: The id of this UserSiteCommonModelsBasicUserInfo.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this UserSiteCommonModelsBasicUserInfo.


        :param id: The id of this UserSiteCommonModelsBasicUserInfo.
        :type: str
        """

        self._id = id

    @property
    def first_name(self):
        # type: () -> str
        """Gets the first_name of this UserSiteCommonModelsBasicUserInfo.


        :return: The first_name of this UserSiteCommonModelsBasicUserInfo.
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this UserSiteCommonModelsBasicUserInfo.


        :param first_name: The first_name of this UserSiteCommonModelsBasicUserInfo.
        :type: str
        """

        self._first_name = first_name

    @property
    def last_name(self):
        # type: () -> str
        """Gets the last_name of this UserSiteCommonModelsBasicUserInfo.


        :return: The last_name of this UserSiteCommonModelsBasicUserInfo.
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this UserSiteCommonModelsBasicUserInfo.


        :param last_name: The last_name of this UserSiteCommonModelsBasicUserInfo.
        :type: str
        """

        self._last_name = last_name

    @property
    def user_name(self):
        # type: () -> str
        """Gets the user_name of this UserSiteCommonModelsBasicUserInfo.


        :return: The user_name of this UserSiteCommonModelsBasicUserInfo.
        :rtype: str
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        """Sets the user_name of this UserSiteCommonModelsBasicUserInfo.


        :param user_name: The user_name of this UserSiteCommonModelsBasicUserInfo.
        :type: str
        """

        self._user_name = user_name

    @property
    def email(self):
        # type: () -> str
        """Gets the email of this UserSiteCommonModelsBasicUserInfo.


        :return: The email of this UserSiteCommonModelsBasicUserInfo.
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this UserSiteCommonModelsBasicUserInfo.


        :param email: The email of this UserSiteCommonModelsBasicUserInfo.
        :type: str
        """

        self._email = email

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in self.swagger_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(UserSiteCommonModelsBasicUserInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserSiteCommonModelsBasicUserInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UserSiteCommonModelsBasicUserInfo):
            return True

        return self.to_dict() != other.to_dict()
